==> code-browser-2.19-src.tar.gz: code-browser-2.19/macospackaging/build-app.sh <==
#! /bin/bash
#
# This script attempts to build an Code Browser.app package for OS X, resolving
# dynamic libraries, etc. 
#
# Author:
#    Damien Doiselet <damien.doiselet@ddmicrolog.org>
# 
# Copyright (C) 2007 Damien Doiselet
#
# Released under GNU GPL
#
# Based on osx-app.sh from inkscape project
#


# We're on Tiger (10.4) or later.
# XCode behaves a little differently in Tiger and later.
SCRIPTEXECDIR="Script_Exec/build/Release/ScriptExec.app/Contents/MacOS"

if [ -z $LIBPREFIX ]
then
	export LIBPREFIX="/opt/local"
fi

# Package always has the same name.  Version information is stored in
# the Info.plist file which is filled in by the configure script.
pkg="Code Browser"
package="$pkg.app"
binary=../code-browser
plist=Info.plist
resdir=`pwd`

mkdir -p "$package"/Contents/MacOS
mkdir -p "$package"/Contents/Resources/bin
mkdir -p "$package"/Contents/Resources/lib
mkdir -p "$package"/Contents/Resources/share/code-browser

binname=`basename "$binary"`
binpath="$package/Contents/Resources/bin/code-browser"


# Build and add the launcher.
(
  # Build fails if CC happens to be set (to anything other than CompileC)
  unset CC
  
  cd "$resdir/Script_Exec"
  xcodebuild $XCODEFLAGS clean build
)
cp "$resdir/$SCRIPTEXECDIR/ScriptExec" "$package/Contents/MacOS/Code Browser"
rsync -av "$resdir/$SCRIPTEXECDIR/../Resources/English.lproj" "$package/Contents/Resources/"

cp "$plist" "$package/Contents/Info.plist"

# PkgInfo must match bundle type and creator code from Info.plist
echo "APPLInks" > "$package/Contents/PkgInfo"

if [ "$1" = "" ]; then
	cp "$binary" "$binpath"
	# Pull in extra requirements.
	pkgetc="$package/Contents/Resources/etc"
	mkdir -p "$pkgetc/pango"
	#sed -e "s,$LIBPREFIX,\"\${CWD}\",g" $LIBPREFIX/etc/pango/pangox.aliases > "$pkgetc/pango/pangox.aliases"
	#sed -e "s,$LIBPREFIX,\"\${CWD}\",g" $LIBPREFIX/etc/pango/pango.modules > "$pkgetc/pango/pango.modules"
	#sed -e "s,$LIBPREFIX,\"\${CWD}\",g" $LIBPREFIX/etc/pango/pangorc > "$pkgetc/pango/pangorc"
	sed -e "s,$LIBPREFIX,\"\${CWD},g" -e 's,\.so ,.so" ,g' $LIBPREFIX/etc/pango/pango.modules > "$pkgetc/pango/pango.modules"
	sed -e "s,$LIBPREFIX/etc\(.*$\),\"\${CWD}\1\",g" $LIBPREFIX/etc/pango/pangorc > "$pkgetc/pango/pangorc"


	cp $LIBPREFIX/etc/pango/pangox.aliases "$pkgetc/pango/"
	#cp $LIBPREFIX/etc/pango/pango.modules "$pkgetc/pango/"
	#cp $LIBPREFIX/etc/pango/pangorc "$pkgetc/pango/"

	# We use a modified fonts.conf file so only need the dtd
	mkdir -p "$pkgetc/fonts"
	cp $LIBPREFIX/etc/fonts/fonts.dtd "$pkgetc/fonts/"
	cp $LIBPREFIX/etc/fonts/fonts.conf "$pkgetc/fonts/"
	cp -r $LIBPREFIX/etc/fonts/conf.avail "$pkgetc/fonts/"
	cp -r $LIBPREFIX/etc/fonts/conf.d "$pkgetc/fonts/"


	mkdir -p "$pkgetc/gtk-2.0"
	sed -e "s,$LIBPREFIX,\${CWD},g" $LIBPREFIX/etc/gtk-2.0/gdk-pixbuf.loaders > "$pkgetc/gtk-2.0/gdk-pixbuf.loaders"
	sed -e "s,$LIBPREFIX,\${CWD},g" $LIBPREFIX/etc/gtk-2.0/gtk.immodules > "$pkgetc/gtk-2.0/gtk.immodules"

	pkglib="$package/Contents/Resources/lib"
	pangover=`ls $LIBPREFIX/lib/pango/`
	mkdir -p "$pkglib"/pango/$pangover/modules
	cp $LIBPREFIX/lib/pango/$pangover/modules/*.so "$pkglib"/pango/$pangover/modules/

	gtkver=`ls $LIBPREFIX/lib/gtk-2.0/ | grep "2\."`
	mkdir -p "$pkglib"/gtk-2.0/$gtkver/{engines,immodules,loaders}
	cp -r $LIBPREFIX/lib/gtk-2.0/$gtkver/engines/* "$pkglib"/gtk-2.0/$gtkver/engines/
	cp $LIBPREFIX/lib/gtk-2.0/$gtkver/immodules/*.so "$pkglib"/gtk-2.0/$gtkver/immodules/
	cp $LIBPREFIX/lib/gtk-2.0/$gtkver/loaders/*.so "$pkglib"/gtk-2.0/$gtkver/loaders/

	# Find out libs we need from fink, darwinports, or from a custom install
	# (e.g. $LIBPREFIX), then loop until no changes.
	a=1
	nfiles=0
	endl=true
	while $endl; do
		echo "Looking for dependencies. Round " $a
		#libs="`otool -L $pkglib/gtk-2.0/$gtkver/loaders/* $pkglib/gtk-2.0/$gtkver/immodules/* $pkglib/gtk-2.0/$gtkver/engines/*.so $pkglib/pango/$pangover/modules/* $pkglib/gnome-vfs-2.0/modules/* $package/Contents/Resources/lib/* $binary 2>/dev/null | fgrep compatibility | cut -d\( -f1 | grep $LIBPREFIX | sort | uniq`"
		libs="`otool -L $pkglib/pango/$pangover/modules/* "$package"/Contents/Resources/lib/* "$binary" 2>/dev/null | fgrep compatibility | cut -d\( -f1 | grep $LIBPREFIX | sort | uniq`"
		cp -f $libs "$package/"Contents/Resources/lib
		let "a+=1"  
		nnfiles=`ls "$package"/Contents/Resources/lib | wc -l`
		if [ $nnfiles = $nfiles ]; then
			endl=false
		else
			nfiles=$nnfiles
		fi
	done

	for libfile in $EXTRALIBS
	do
		cp -f $libfile "$package"/Contents/Resources/lib
	done

	if [ "$strip" = "true" ]; then
		chmod +w "$package"/Contents/Resources/lib/*.dylib
		strip -x "$package"/Contents/Resources/lib/*.dylib
		strip -ur "$binpath"
	fi
fi

# Get all the icons and the rest of the script framework
cp -r $resdir/Resources/appIcon.icns "$package/Contents/Resources/"
cp $resdir/Resources/AppSettings.plist "$package/Contents/Resources/"
cp $resdir/Resources/script "$package/Contents/Resources/"
if [ "$1" = "" ]; then
  cp -r $resdir/Resources/bin "$package/Contents/Resources/"
  echo "\"\$CWD/start-code-browser\" \"\$FILES\"" >> "$package/Contents/Resources/script"
else
  echo "$1 \"\$FILES\"" >> "$package/Contents/Resources/script"
fi


touch "$package/Contents/Resources/.script"

# Copy configuration files
rsync -av $resdir/../config "$package/Contents/Resources/share/code-browser/"
rsync -av $resdir/../config-default "$package/Contents/Resources/share/code-browser/"
rsync -av $resdir/../config-optional "$package/Contents/Resources/share/code-browser/"

mv "$package" ../

==> code-browser-3.6-src.tar.gz: code-browser-3.6/macospackaging/build-app.sh <==
#! /bin/bash
#
# This script attempts to build an Code Browser.app package for OS X, resolving
# dynamic libraries, etc. 
#
# Author:
#    Damien Doiselet <damien.doiselet@ddmicrolog.org>
# 
# Copyright (C) 2007 Damien Doiselet
#
# Released under GNU GPL
#
# Based on osx-app.sh from inkscape project
#


# We're on Tiger (10.4) or later.
# XCode behaves a little differently in Tiger and later.
SCRIPTEXECDIR="Script_Exec/build/Release/ScriptExec.app/Contents/MacOS"

if [ -z $LIBPREFIX ]
then
	export LIBPREFIX="/opt/local"
fi

# Package always has the same name.  Version information is stored in
# the Info.plist file which is filled in by the configure script.
pkg="Code Browser"
package="$pkg.app"
binary=../code-browser
plist=Info.plist
resdir=`pwd`

mkdir -p "$package"/Contents/MacOS
mkdir -p "$package"/Contents/Resources/bin
mkdir -p "$package"/Contents/Resources/lib
mkdir -p "$package"/Contents/Resources/share/code-browser

binname=`basename "$binary"`
binpath="$package/Contents/Resources/bin/code-browser"


# Build and add the launcher.
(
  # Build fails if CC happens to be set (to anything other than CompileC)
  unset CC
  
  cd "$resdir/Script_Exec"
  xcodebuild $XCODEFLAGS clean build
)
cp "$resdir/$SCRIPTEXECDIR/ScriptExec" "$package/Contents/MacOS/Code Browser"
rsync -av "$resdir/$SCRIPTEXECDIR/../Resources/English.lproj" "$package/Contents/Resources/"

cp "$plist" "$package/Contents/Info.plist"

# PkgInfo must match bundle type and creator code from Info.plist
echo "APPLInks" > "$package/Contents/PkgInfo"

if [ "$1" = "" ]; then
	cp "$binary" "$binpath"
	# Pull in extra requirements.
	pkgetc="$package/Contents/Resources/etc"
	mkdir -p "$pkgetc/pango"
	#sed -e "s,$LIBPREFIX,\"\${CWD}\",g" $LIBPREFIX/etc/pango/pangox.aliases > "$pkgetc/pango/pangox.aliases"
	#sed -e "s,$LIBPREFIX,\"\${CWD}\",g" $LIBPREFIX/etc/pango/pango.modules > "$pkgetc/pango/pango.modules"
	#sed -e "s,$LIBPREFIX,\"\${CWD}\",g" $LIBPREFIX/etc/pango/pangorc > "$pkgetc/pango/pangorc"
	sed -e "s,$LIBPREFIX,\"\${CWD},g" -e 's,\.so ,.so" ,g' $LIBPREFIX/etc/pango/pango.modules > "$pkgetc/pango/pango.modules"
	sed -e "s,$LIBPREFIX/etc\(.*$\),\"\${CWD}\1\",g" $LIBPREFIX/etc/pango/pangorc > "$pkgetc/pango/pangorc"


	cp $LIBPREFIX/etc/pango/pangox.aliases "$pkgetc/pango/"
	#cp $LIBPREFIX/etc/pango/pango.modules "$pkgetc/pango/"
	#cp $LIBPREFIX/etc/pango/pangorc "$pkgetc/pango/"

	# We use a modified fonts.conf file so only need the dtd
	mkdir -p "$pkgetc/fonts"
	cp $LIBPREFIX/etc/fonts/fonts.dtd "$pkgetc/fonts/"
	cp $LIBPREFIX/etc/fonts/fonts.conf "$pkgetc/fonts/"
	cp -r $LIBPREFIX/etc/fonts/conf.avail "$pkgetc/fonts/"
	cp -r $LIBPREFIX/etc/fonts/conf.d "$pkgetc/fonts/"


	mkdir -p "$pkgetc/gtk-2.0"
	sed -e "s,$LIBPREFIX,\${CWD},g" $LIBPREFIX/etc/gtk-2.0/gdk-pixbuf.loaders > "$pkgetc/gtk-2.0/gdk-pixbuf.loaders"
	sed -e "s,$LIBPREFIX,\${CWD},g" $LIBPREFIX/etc/gtk-2.0/gtk.immodules > "$pkgetc/gtk-2.0/gtk.immodules"

	pkglib="$package/Contents/Resources/lib"
	pangover=`ls $LIBPREFIX/lib/pango/`
	mkdir -p "$pkglib"/pango/$pangover/modules
	cp $LIBPREFIX/lib/pango/$pangover/modules/*.so "$pkglib"/pango/$pangover/modules/

	gtkver=`ls $LIBPREFIX/lib/gtk-2.0/ | grep "2\."`
	mkdir -p "$pkglib"/gtk-2.0/$gtkver/{engines,immodules,loaders}
	cp -r $LIBPREFIX/lib/gtk-2.0/$gtkver/engines/* "$pkglib"/gtk-2.0/$gtkver/engines/
	cp $LIBPREFIX/lib/gtk-2.0/$gtkver/immodules/*.so "$pkglib"/gtk-2.0/$gtkver/immodules/
	cp $LIBPREFIX/lib/gtk-2.0/$gtkver/loaders/*.so "$pkglib"/gtk-2.0/$gtkver/loaders/

	# Find out libs we need from fink, darwinports, or from a custom install
	# (e.g. $LIBPREFIX), then loop until no changes.
	a=1
	nfiles=0
	endl=true
	while $endl; do
		echo "Looking for dependencies. Round " $a
		#libs="`otool -L $pkglib/gtk-2.0/$gtkver/loaders/* $pkglib/gtk-2.0/$gtkver/immodules/* $pkglib/gtk-2.0/$gtkver/engines/*.so $pkglib/pango/$pangover/modules/* $pkglib/gnome-vfs-2.0/modules/* $package/Contents/Resources/lib/* $binary 2>/dev/null | fgrep compatibility | cut -d\( -f1 | grep $LIBPREFIX | sort | uniq`"
		libs="`otool -L $pkglib/pango/$pangover/modules/* "$package"/Contents/Resources/lib/* "$binary" 2>/dev/null | fgrep compatibility | cut -d\( -f1 | grep $LIBPREFIX | sort | uniq`"
		cp -f $libs "$package/"Contents/Resources/lib
		let "a+=1"  
		nnfiles=`ls "$package"/Contents/Resources/lib | wc -l`
		if [ $nnfiles = $nfiles ]; then
			endl=false
		else
			nfiles=$nnfiles
		fi
	done

	for libfile in $EXTRALIBS
	do
		cp -f $libfile "$package"/Contents/Resources/lib
	done

	if [ "$strip" = "true" ]; then
		chmod +w "$package"/Contents/Resources/lib/*.dylib
		strip -x "$package"/Contents/Resources/lib/*.dylib
		strip -ur "$binpath"
	fi
fi

# Get all the icons and the rest of the script framework
cp -r $resdir/Resources/appIcon.icns "$package/Contents/Resources/"
cp $resdir/Resources/AppSettings.plist "$package/Contents/Resources/"
cp $resdir/Resources/script "$package/Contents/Resources/"
if [ "$1" = "" ]; then
  cp -r $resdir/Resources/bin "$package/Contents/Resources/"
  echo "\"\$CWD/start-code-browser\" \"\$FILES\"" >> "$package/Contents/Resources/script"
else
  echo "$1 \"\$FILES\"" >> "$package/Contents/Resources/script"
fi


touch "$package/Contents/Resources/.script"

# Copy configuration files
rsync -av $resdir/../config "$package/Contents/Resources/share/code-browser-3/"
rsync -av $resdir/../config-default "$package/Contents/Resources/share/code-browser-3/"
rsync -av $resdir/../config-optional "$package/Contents/Resources/share/code-browser-3/"

mv "$package" ../
